@@ -5,5 +5,4 @@
 "mytime" <- function( ) {format(Sys.time(), "%X")
 }
 
-"mydate" <- function( ) {format(Sys.time(), "%Y-%m-%d")
-}
+"mydate" <- function( ) format(Sys.time(), "%Y-%m-%d")
